@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2013 Aurélien Gateau <agateau@kde.org>
+    SPDX-FileCopyrightText: 2013 Aurélien Gateau <agateau@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "klinkitemselectionmodeltest.h"
@@ -48,13 +35,13 @@ void KLinkItemSelectionModelTest::init()
 void KLinkItemSelectionModelTest::cleanup()
 {
     delete m_mainSelectionModel;
-    m_mainSelectionModel = 0;
+    m_mainSelectionModel = nullptr;
     delete m_mainModel;
-    m_mainModel = 0;
+    m_mainModel = nullptr;
     delete m_subSelectionModel;
-    m_subSelectionModel = 0;
+    m_subSelectionModel = nullptr;
     delete m_subModel;
-    m_subModel = 0;
+    m_subModel = nullptr;
 }
 
 void KLinkItemSelectionModelTest::testToggle()
@@ -170,7 +157,7 @@ void KLinkItemSelectionModelTest::testChangeLinkedSelectionModel()
     QCOMPARE(m_mainSelectionModel->selection().indexes().first().row(), 6);
     QCOMPARE(m_subSelectionModel->selection().indexes().first().row(), 1);
 
-    QItemSelectionModel replacementSelectionModel(m_mainModel, 0);
+    QItemSelectionModel replacementSelectionModel(m_mainModel, nullptr);
     {
     auto idx = m_mainModel->index(7, 0);
     replacementSelectionModel.select(idx, QItemSelectionModel::Select);
