@@ -1,27 +1,13 @@
 /*
-    Copyright (c) 2009 Stephen Kelly <steveire@gmail.com>
+    SPDX-FileCopyrightText: 2009 Stephen Kelly <steveire@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dynamictreemodel.h"
 
 #include <QHash>
 #include <QList>
-#include <QTimer>
 #include <QMimeData>
 
 #include <QDebug>
@@ -195,7 +181,8 @@ bool DynamicTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction action
     int _row;
     static const int column = 0;
     QHash<qint64, QList<QList<qint64> > >::const_iterator it;
-    Q_FOREACH (const QByteArray &ba, encoded.split('\0')) {
+    const auto lst = encoded.split('\0');
+    for (const QByteArray &ba : lst) {
         id = ba.toInt(&ok);
         if (!ok) {
             qDebug() << ba;
@@ -237,7 +224,7 @@ bool DynamicTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction action
         srcPath = indexToPath(srcParent);
 
         rowsMoved = src_parent_it.value();
-        qSort(rowsMoved);
+        std::sort(rowsMoved.begin(), rowsMoved.end());
         src_row_it = rowsMoved.begin();
         rows_moved_end = rowsMoved.end();
         startRow = *src_row_it;
@@ -281,7 +268,7 @@ bool DynamicTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction action
     }
 
     int offset = firstCommand->endRow() - firstCommand->startRow() + 1;
-    Q_FOREACH (ModelMoveCommand *moveCommand, moveCommands) {
+    for (ModelMoveCommand *moveCommand : qAsConst(moveCommands)) {
         moveCommand->setDestAncestors(indexToPath(destParent));
         moveCommand->setDestRow(destRowIndex.row() + offset);
         moveCommand->doCommand();
@@ -433,10 +420,9 @@ void ModelInsertCommand::interpret(const QString &treeString)
 {
     m_treeString = treeString;
 
-    QList<int> depths = getDepths(m_treeString);
+    const QList<int> depths = getDepths(m_treeString);
 
-    int size = 0;
-    qCount(depths, 0, size);
+    const int size = std::count(depths.begin(), depths.end(), 0);
     Q_ASSERT(size != 0);
 
     m_endRow = m_startRow + size - 1;
@@ -480,10 +466,8 @@ void ModelInsertCommand::doCommand()
     QModelIndex parent = findIndex(m_rowNumbers);
 
     if (!m_treeString.isEmpty()) {
-        QList<int> depths = getDepths(m_treeString);
-
-        int size = 0;
-        qCount(depths, 0, size);
+        const QList<int> depths = getDepths(m_treeString);
+        const int size = std::count(depths.begin(), depths.end(), 0);
         Q_ASSERT(size != 0);
         m_endRow = m_startRow + size - 1;
     }
@@ -512,7 +496,7 @@ void ModelInsertCommand::doCommand()
 
 void ModelInsertCommand::doInsertTree(const QModelIndex &fragmentParent)
 {
-    QList<int> depths = getDepths(m_treeString);
+    const QList<int> depths = getDepths(m_treeString);
 
     qint64 fragmentParentIdentifier = fragmentParent.internalId();
 
@@ -599,10 +583,10 @@ void ModelInsertAndRemoveQueuedCommand::purgeItem(qint64 parent)
 {
     QList<QList<qint64> > childItemRows = m_model->m_childItems.value(parent);
 
-    if (childItemRows.size() > 0) {
+    if (!childItemRows.isEmpty()) {
         for (int col = 0; col < m_numCols; col++) {
-            QList<qint64> childItems = childItemRows[col];
-            Q_FOREACH (qint64 item, childItems) {
+            const QList<qint64> childItems = childItemRows[col];
+            for (qint64 item : childItems) {
                 purgeItem(item);
                 m_model->m_childItems[parent][col].removeOne(item);
             }
@@ -679,12 +663,12 @@ void ModelRemoveCommand::doCommand()
 
 void ModelRemoveCommand::purgeItem(qint64 parent)
 {
-    QList<QList<qint64> > childItemRows = m_model->m_childItems.value(parent);
+    const QList<QList<qint64> > childItemRows = m_model->m_childItems.value(parent);
 
-    if (childItemRows.size() > 0) {
+    if (!childItemRows.isEmpty()) {
         for (int col = 0; col < m_numCols; col++) {
-            QList<qint64> childItems = childItemRows[col];
-            Q_FOREACH (qint64 item, childItems) {
+            const QList<qint64> childItems = childItemRows[col];
+            for (qint64 item : childItems) {
                 purgeItem(item);
                 m_model->m_childItems[parent][col].removeOne(item);
             }
@@ -737,7 +721,7 @@ void ModelMoveCommand::doCommand()
     }
 
     for (int column = 0; column < m_numCols; ++column) {
-        QList<qint64> l = m_model->m_childItems.value(srcParent.internalId())[column].mid(m_startRow, m_endRow - m_startRow + 1);
+        const QList<qint64> l = m_model->m_childItems.value(srcParent.internalId())[column].mid(m_startRow, m_endRow - m_startRow + 1);
 
         for (int i = m_startRow; i <= m_endRow; i++) {
             m_model->m_childItems[srcParent.internalId()][column].removeAt(m_startRow);
@@ -753,7 +737,7 @@ void ModelMoveCommand::doCommand()
             }
         }
 
-        Q_FOREACH (const qint64 id, l) {
+        for (const qint64 id : l) {
 
             if (!m_model->m_childItems.contains(destParent.internalId())) {
                 m_model->m_childItems[destParent.internalId()].append(QList<qint64>());
@@ -926,7 +910,7 @@ void ModelLayoutChangeCommand::doCommand()
     m_model->layoutAboutToBeChanged();
     QModelIndexList oldList;
 
-    Q_FOREACH (const PersistentChange &change, m_changes) {
+    for (const PersistentChange &change : qAsConst(m_changes)) {
         const IndexFinder oldFinder(m_model, change.oldPath);
         oldList << oldFinder.getIndex();
     }
@@ -941,7 +925,7 @@ void ModelLayoutChangeCommand::doCommand()
     }
 
     QModelIndexList newList;
-    Q_FOREACH (const PersistentChange &change, m_changes) {
+    for (const PersistentChange &change : qAsConst(m_changes)) {
         const IndexFinder newFinder(m_model, change.newPath);
         newList << newFinder.getIndex();
     }
