@@ -1,27 +1,13 @@
 /*
-    Copyright (c) 2009 Stephen Kelly <steveire@gmail.com>
+    SPDX-FileCopyrightText: 2009 Stephen Kelly <steveire@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "proxymodeltest.h"
 
 #include "dynamictreemodel.h"
 
-#include <QItemSelectionModel>
 #include <QSortFilterProxyModel>
 
 #include "modelspy.h"
@@ -30,8 +16,8 @@ ProxyModelTest::ProxyModelTest(QObject *parent)
     : QObject(parent),
       m_rootModel(new DynamicTreeModel(this)),
       m_sourceModel(m_rootModel),
-      m_proxyModel(0),
-      m_intermediateProxyModel(0),
+      m_proxyModel(nullptr),
+      m_intermediateProxyModel(nullptr),
       m_modelSpy(new ModelSpy(this)),
       m_modelCommander(new ModelCommander(m_rootModel, this))
 {
@@ -86,9 +72,9 @@ void ProxyModelTest::verifyExecutedTests()
     if (m_dataTags.contains(ProxyModelTestData::failTag())) {
         return;
     }
-    QSet<QString> unimplemented = m_modelCommanderTags.toSet().subtract(m_dataTags.toSet());
+    const QSet<QString> unimplemented = m_modelCommanderTags.toSet().subtract(m_dataTags.toSet());
     QString unimplementedTestsString(QStringLiteral("("));
-    Q_FOREACH (const QString &test, unimplemented) {
+    for (const QString &test : unimplemented) {
         unimplementedTestsString.append(test + ",");
     }
     unimplementedTestsString.append(")");
@@ -108,7 +94,7 @@ void ProxyModelTest::init()
 
     const char *currentTest = QTest::currentTestFunction();
     const char *currentTag = QTest::currentDataTag();
-    QVERIFY(currentTest != 0);
+    QVERIFY(currentTest != nullptr);
     initRootModel(m_rootModel, currentTest, currentTag);
 
     Q_ASSERT(sourceModel());
@@ -143,10 +129,10 @@ void ProxyModelTest::cleanup()
 {
     QVERIFY(m_modelSpy->isEmpty());
     m_modelSpy->stopSpying();
-    m_modelSpy->setModel(0);
-    m_proxyModel->setSourceModel(0);
+    m_modelSpy->setModel(nullptr);
+    m_proxyModel->setSourceModel(nullptr);
     delete m_proxyModel;
-    m_proxyModel = 0;
+    m_proxyModel = nullptr;
     QVERIFY(m_modelSpy->isEmpty());
 }
 
@@ -160,7 +146,7 @@ void ProxyModelTest::cleanupTestCase()
 
     m_sourceModel = m_rootModel;
     delete m_intermediateProxyModel;
-    m_intermediateProxyModel = 0;
+    m_intermediateProxyModel = nullptr;
 
     m_modelSpy->clear();
 }
@@ -189,7 +175,7 @@ void ProxyModelTest::handleSignal(QVariantList expected)
     QVariantList result = getResultSignal();
 
     QCOMPARE(result.takeAt(0).toInt(), signalType);
-    // Check that the signal we expected to recieve was emitted exactly.
+    // Check that the signal we expected to receive was emitted exactly.
     switch (signalType) {
     case RowsAboutToBeInserted:
     case RowsInserted:
@@ -303,7 +289,7 @@ void ProxyModelTest::testSourceReset()
     ModelInsertCommand *ins = new ModelInsertCommand(m_rootModel, this);
     ins->setStartRow(0);
     ins->interpret(
-        QString("- 1"
+        QLatin1String("- 1"
         "- 2"
         "- - 3"
         "- - 4"
@@ -320,7 +306,7 @@ void ProxyModelTest::testSourceReset()
     testMappings();
     m_rootModel->clear(); // Resets the model.
     testMappings(); // Calls some rowCount() etc which should test internal structures in the proxy.
-    m_proxyModel->setSourceModel(0);
+    m_proxyModel->setSourceModel(nullptr);
 
     m_modelSpy->startSpying();
 }
@@ -334,7 +320,7 @@ void ProxyModelTest::testDestroyModel()
     ModelInsertCommand *ins = new ModelInsertCommand(rootModel, this);
     ins->setStartRow(0);
     ins->interpret(
-        QString(" - 1"
+        QLatin1String(" - 1"
         " - 1"
         " - - 1"
         " - 1"
@@ -352,7 +338,7 @@ void ProxyModelTest::testDestroyModel()
     if (proxyModel->hasChildren()) {
         m_modelSpy->startSpying();
         delete m_sourceModel;
-        m_sourceModel = 0;
+        m_sourceModel = nullptr;
         m_modelSpy->stopSpying();
         testMappings();
 //     QCOMPARE(m_modelSpy->size(), 1);
@@ -479,8 +465,8 @@ void ProxyModelTest::connectProxy(QAbstractProxyModel *proxyModel)
     m_modelSpy->stopSpying();
 
     QVERIFY(m_modelSpy->size() == 2);
-    QVERIFY(m_modelSpy->takeFirst().first() == ModelAboutToBeReset);
-    QVERIFY(m_modelSpy->takeFirst().first() == ModelReset);
+    QVERIFY(m_modelSpy->takeFirst().at(0) == ModelAboutToBeReset);
+    QVERIFY(m_modelSpy->takeFirst().at(0) == ModelReset);
     QVERIFY(m_modelSpy->isEmpty());
     testMappings();
 
@@ -552,7 +538,7 @@ void ProxyModelTest::doTest()
     }
 
     static int numTests = 0;
-    if (qApp->arguments().contains(QStringLiteral("-count"))) {
+    if (qApp->arguments().contains(QLatin1String("-count"))) {
         qDebug() << "numTests" << ++numTests;
     }
 
@@ -577,7 +563,7 @@ void ProxyModelTest::doTest()
     const bool isLayoutChange = signalList.contains(QVariantList() << LayoutAboutToBeChanged);
 
     while (!signalList.isEmpty()) {
-        // Process each signal we recieved as a result of running the test.
+        // Process each signal we received as a result of running the test.
         QVariantList expected = signalList.takeAt(0);
         handleSignal(expected);
     }
@@ -586,7 +572,8 @@ void ProxyModelTest::doTest()
     QVERIFY(m_modelSpy->isEmpty());
 
     // Persistent indexes should change by the amount described in change objects.
-    Q_FOREACH (PersistentIndexChange change, m_modelSpy->getChangeList()) {
+    const auto lst = m_modelSpy->getChangeList();
+    for (PersistentIndexChange change : lst) {
         for (int i = 0; i < change.indexes.size(); i++) {
             QModelIndex idx = change.indexes.at(i);
             QPersistentModelIndex persistentIndex = change.persistentIndexes.at(i);
@@ -641,9 +628,9 @@ void ProxyModelTest::doTest()
     m_modelSpy->clearTestData();
 }
 
-void ProxyModelTest::connectTestSignals(QObject *reciever)
+void ProxyModelTest::connectTestSignals(QObject *receiver)
 {
-    if (!reciever) {
+    if (!receiver) {
         return;
     }
     for (int methodIndex = 0; methodIndex < metaObject()->methodCount(); ++methodIndex) {
@@ -651,16 +638,16 @@ void ProxyModelTest::connectTestSignals(QObject *reciever)
         if (mm.methodType() == QMetaMethod::Signal
                 && QString(mm.methodSignature()).startsWith(QLatin1String("test"))
                 && QString(mm.methodSignature()).endsWith(QLatin1String("Data()"))) {
-            int slotIndex = reciever->metaObject()->indexOfSlot(mm.methodSignature());
+            int slotIndex = receiver->metaObject()->indexOfSlot(mm.methodSignature());
             Q_ASSERT(slotIndex >= 0);
-            metaObject()->connect(this, methodIndex, reciever, slotIndex);
+            metaObject()->connect(this, methodIndex, receiver, slotIndex);
         }
     }
 }
 
-void ProxyModelTest::disconnectTestSignals(QObject *reciever)
+void ProxyModelTest::disconnectTestSignals(QObject *receiver)
 {
-    if (!reciever) {
+    if (!receiver) {
         return;
     }
     for (int methodIndex = 0; methodIndex < metaObject()->methodCount(); ++methodIndex) {
@@ -668,9 +655,9 @@ void ProxyModelTest::disconnectTestSignals(QObject *reciever)
         if (mm.methodType() == QMetaMethod::Signal
                 && QString(mm.methodSignature()).startsWith(QLatin1String("test"))
                 && QString(mm.methodSignature()).endsWith(QLatin1String("Data()"))) {
-            int slotIndex = reciever->metaObject()->indexOfSlot(mm.methodSignature());
+            int slotIndex = receiver->metaObject()->indexOfSlot(mm.methodSignature());
             Q_ASSERT(slotIndex >= 0);
-            metaObject()->disconnect(this, methodIndex, reciever, slotIndex);
+            metaObject()->disconnect(this, methodIndex, receiver, slotIndex);
         }
     }
 }
