@@ -1,25 +1,11 @@
 /*
-    Copyright (c) 2009 Stephen Kelly <steveire@gmail.com>
+    SPDX-FileCopyrightText: 2009 Stephen Kelly <steveire@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kreparentingproxymodel.h"
 #include <QDebug>
-#include <QStack>
 
 #include <functional>
 #include <algorithm>
@@ -221,7 +207,7 @@ QModelIndex KReparentingProxyModelPrivate::getLastDescendant(const QModelIndex &
     QModelIndex proxyIndex = q->mapFromSource(index);
 
     while (q->hasChildren(proxyIndex)) {
-        proxyIndex = proxyIndex.child(q->rowCount(proxyIndex), proxyIndex.column());
+        proxyIndex = q->index(q->rowCount(proxyIndex), proxyIndex.column(), proxyIndex);
         if (!proxyIndex.isValid()) {
             break;
         }
@@ -309,7 +295,7 @@ QHash<QModelIndex, QModelIndexList> KReparentingProxyModelPrivate::recreateMappi
             break;
         }
 
-        const QVector<QModelIndex>::iterator ancestorIt = qLowerBound(ancestors.begin(), ancestors.end(), nextIndex, LessThan(q));
+        const QVector<QModelIndex>::iterator ancestorIt = std::lower_bound(ancestors.begin(), ancestors.end(), nextIndex, LessThan(q));
 
         ancestors.erase(ancestorIt, ancestors.end());
 
@@ -539,7 +525,7 @@ QModelIndex KReparentingProxyModel::mapToSource(const QModelIndex &proxyIndex) c
     if (d->m_pendingRemovalChildIndexes.contains(sourceParent)) {
 //     qDebug() << "#############";
 
-        Q_FOREACH (const KReparentingProxyModelPrivate::PendingRemoval &pendingRemoval, d->m_pendingRemovals) {
+        for (const KReparentingProxyModelPrivate::PendingRemoval &pendingRemoval : qAsConst(d->m_pendingRemovals)) {
 //       qDebug() << "In" << pendingRemoval.index << pendingRemoval.sourceIndex << sourceParent;
             if (pendingRemoval.sourceIndex == sourceParent) {
 //         qDebug() << "Out" << pendingRemoval.sourceIndex << sourceParent;
@@ -666,7 +652,7 @@ QModelIndex KReparentingProxyModel::parent(const QModelIndex &child) const
 int KReparentingProxyModelPrivate::pendingRemovalRowCount(const QModelIndex &sourceIndex) const
 {
 
-    Q_FOREACH (const PendingRemoval &pendingRemoval, m_pendingRemovals) {
+    for (const PendingRemoval &pendingRemoval : qAsConst(m_pendingRemovals)) {
 //     qDebug() << pendingRemoval.sourceIndex;
         if (pendingRemoval.sourceIndex == sourceIndex) {
             return pendingRemoval.end - pendingRemoval.start + 1;
@@ -782,7 +768,7 @@ void KReparentingProxyModelPrivate::sourceRowsAboutToBeInserted(const QModelInde
 
 QHash<QModelIndex, QModelIndexList> KReparentingProxyModelPrivate::mergeDescendants(QHash<QModelIndex, QModelIndexList> mappings, const QModelIndex &parent, int start)
 {
-    QModelIndexList childIndexes = mappings.take(parent);
+    const QModelIndexList childIndexes = mappings.take(parent);
 //   qDebug() << childIndexes;
     if (!childIndexes.isEmpty()) {
         if (!m_parents.values().contains(parent)) {
@@ -790,7 +776,7 @@ QHash<QModelIndex, QModelIndexList> KReparentingProxyModelPrivate::mergeDescenda
         }
     }
     int row = start;
-    Q_FOREACH (const QModelIndex &idx, childIndexes) {
+    for (const QModelIndex &idx : childIndexes) {
         m_childIndexes[parent].insert(row++, QPersistentModelIndex(idx));
         mappings = mergeDescendants(mappings, idx, 0);
     }
