@@ -1,23 +1,10 @@
 /*
- * This file is part of the proxy model test suite.
- *
- * Copyright 2015 Stephen Kelly <steveire@gmail.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
- */
+    This file is part of the proxy model test suite.
+
+    SPDX-FileCopyrightText: 2015 Stephen Kelly <steveire@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "selectioninqmlwidget.h"
 
@@ -54,5 +41,5 @@ SelectionInQmlWidget::SelectionInQmlWidget(QWidget *parent): QWidget(parent)
     quickView->engine()->rootContext()->setContextProperty(QStringLiteral("_model"), m_rootModel);
     quickView->engine()->rootContext()->setContextProperty(QStringLiteral("_selectionModel"), selectionTree->selectionModel());
 
-    quickView->setSource(QUrl::fromLocalFile(SRC_DIR "/selection.qml"));
+    quickView->setSource(QUrl::fromLocalFile(QLatin1String(SRC_DIR "/selection.qml")));
 }
